==> splide-1.0.x-dev.tar.gz: splide/src/Plugin/Field/FieldFormatter/SplideVanillaWithNavTrait.php <==
<?php

namespace Drupal\splide\Plugin\Field\FieldFormatter;

use Drupal\Component\Utility\Xss;

/**
 * A Trait common for splide vanilla formatters.
 */
trait SplideVanillaWithNavTrait {

  /**
   * {@inheritdoc}
   */
  protected function withElementOverride(array &$build, array $element): void {
    if ($build['#asnavfor']) {
      if ($build['#vanilla']) {
        // Build media item including custom highres video thumbnail.
        // @todo re-check/ refine for Paragraphs, etc.
        $this->blazyOembed->build($element);
      }

      $this->withElementThumbnail($build, $element);
    }
  }

  /**
   * {@inheritdoc}
   */
  protected function withElementThumbnail(array &$build, array $element): void {
    if (!$build['#asnavfor']) {
      return;
    }

    // The settings in $element has updated metadata extracted from media.
    $settings  = $this->formatter->toHashtag($element);
    $entity    = $element['#entity'];
    $delta     = $element['#delta'];
    $item      = $this->formatter->toHashtag($element, 'item', NULL);
    $view_mode = $settings['view_mode'] ?? 'default';
    $_caption  = $settings['nav_caption'] ?? NULL;
    $captions  = [];

    if ($_caption) {
      if ($item && $text = trim($item->{$_caption} ?? '')) {
        $captions = ['#markup' => Xss::filterAdmin($text)];
      }
      else {
        $captions = $this->viewField($entity, $_caption, $view_mode);
      }
    }

    // Thumbnail usages: asNavFor pagers, dot, arrows, photobox thumbnails.
    $tn = $this->formatter->getThumbnail($settings, $item, $captions);
    $build[static::$navId]['items'][$delta] = $tn;
  }

  /**
   * {@inheritdoc}
   *
   * @todo remove post blazy:2.17.
   */
  public function buildElement(array &$build, $entityx, $langcodex) {
    // @todo remove parent::buildElement($build, $entity, $langcode);
    // Supports Vanilla with thumbnail navigation.
    $settings = $this->formatter->toHashtag($build);
    $entity   = $this->formatter->toHashtag($build, 'entity', $entityx);
    $blazies  = $settings['blazies'];

    if ($build['#vanilla'] && $build['#asnavfor']) {
      $delta = $blazies->get('delta');
      $element = [
        '#delta'    => $delta,
        '#entity'   => $entity,
        '#settings' => $settings,
        '#item'     => NULL,
      ];

      // Build media item including custom highres video thumbnail.
      // @todo re-check/ refine for Paragraphs, etc.
      $this->blazyOembed->build($element);

      $this->withElementThumbnail($build, $element);
    }
  }

  /**
   * {@inheritdoc}
   *
   * @todo remove post blazy:2.17.
   */
  protected function buildElementThumbnail(array &$build, array $element) {
    $this->withElementThumbnail($build, $element);
  }

  /**
   * If text pagination is configured, pass strings to the JavaScript.
   */
  protected function checkTextPagination(array $entities) {
    @trigger_error('checkTextPagination is deprecated in splide:1.0.8 and is removed from splide:2.0.0. Use \Drupal\splide\SplideFormatter instead. See https://www.drupal.org/node/3367291', E_USER_DEPRECATED);
  }

}

==> splide-2.0.x-dev.tar.gz: splide/src/Plugin/Field/FieldFormatter/SplideVanillaWithNavTrait.php <==
<?php

namespace Drupal\splide\Plugin\Field\FieldFormatter;

use Drupal\Component\Utility\Xss;

/**
 * A Trait common for splide vanilla formatters.
 */
trait SplideVanillaWithNavTrait {

  /**
   * {@inheritdoc}
   */
  protected function withElementOverride(array &$build, array $element): void {
    if ($build['#asnavfor']) {
      if ($build['#vanilla']) {
        // Build media item including custom highres video thumbnail.
        // @todo re-check/ refine for Paragraphs, etc.
        $this->blazyOembed->build($element);
      }

      $this->withElementThumbnail($build, $element);
    }
  }

  /**
   * {@inheritdoc}
   */
  protected function withElementThumbnail(array &$build, array $element): void {
    if (!$build['#asnavfor']) {
      return;
    }

    // The settings in $element has updated metadata extracted from media.
    $settings  = $this->formatter->toHashtag($element);
    $entity    = $element['#entity'];
    $delta     = $element['#delta'];
    $item      = $this->formatter->toHashtag($element, 'item', NULL);
    $view_mode = $settings['view_mode'] ?? 'default';
    $_caption  = $settings['nav_caption'] ?? NULL;
    $captions  = [];

    if ($_caption) {
      if ($item && $text = trim($item->{$_caption} ?? '')) {
        $captions = ['#markup' => Xss::filterAdmin($text)];
      }
      else {
        $captions = $this->viewField($entity, $_caption, $view_mode);
      }
    }

    // Thumbnail usages: asNavFor pagers, dot, arrows, lightbox thumbnails.
    $tn = $this->formatter->getThumbnail($settings, $item, $captions);
    $build[static::$navId]['items'][$delta] = $tn;
  }

}
